pub struct DenseMle<F: Field> {
pub layer_id: LayerId,
pub mle: MultilinearExtension<F>,
pub mle_indices: Vec<MleIndex<F>>,
}Expand description
An implementation of an Mle using a dense representation.
Fields
layer_id: LayerIdThe ID of the layer this data belongs to.
mle: MultilinearExtension<F>A representation of the MLE on its current state.
mle_indices: Vec<MleIndex<F>>The MleIndices current_mle.
Implementations
Sourceimpl<F: Field> DenseMle<F>
impl<F: Field> DenseMle<F>
Sourcepub fn new_with_prefix_bits(
data: MultilinearExtension<F>,
layer_id: LayerId,
prefix_bits: Vec<bool>,
) -> Self
pub fn new_with_prefix_bits( data: MultilinearExtension<F>, layer_id: LayerId, prefix_bits: Vec<bool>, ) -> Self
Constructs a new DenseMle with specified prefix_bits
todo: change this to create a DenseMle with already specified IndexedBits
Sourcepub fn new_with_indices(
data: &[F],
layer_id: LayerId,
mle_indices: &[MleIndex<F>],
) -> Self
pub fn new_with_indices( data: &[F], layer_id: LayerId, mle_indices: &[MleIndex<F>], ) -> Self
Constructs a new DenseMle with specified MLE indices, normally when we are
trying to construct a new MLE based off of a previous MLE, such as in
crate::layer::matmult::MatMult, but want to preserve the “prefix vars.”
The MLE should not have ever been mutated if this function is ever called, so none of the indices should ever be Indexed here.
Sourcepub fn new_from_iter(iter: impl Iterator<Item = F>, layer_id: LayerId) -> Self
pub fn new_from_iter(iter: impl Iterator<Item = F>, layer_id: LayerId) -> Self
Constructs a new DenseMle from a bookkeeping table represented by
Iterator<Item = F> and LayerId.
Example
use remainder::layer::LayerId;
use shared_types::Fr;
use remainder::mle::dense::DenseMle;
DenseMle::<Fr>::new_from_iter(vec![Fr::one()].into_iter(), LayerId::Input(0));Sourcepub fn new_from_raw(items: Vec<F>, layer_id: LayerId) -> Self
pub fn new_from_raw(items: Vec<F>, layer_id: LayerId) -> Self
Sourcepub fn new_from_multilinear_extension(
mle: MultilinearExtension<F>,
layer_id: LayerId,
prefix_vars: Option<Vec<bool>>,
maybe_starting_var_index: Option<usize>,
) -> Self
pub fn new_from_multilinear_extension( mle: MultilinearExtension<F>, layer_id: LayerId, prefix_vars: Option<Vec<bool>>, maybe_starting_var_index: Option<usize>, ) -> Self
Constructs a new DenseMle from a MultilinearExtension, additionally being able to specify the prefix vars and layer ID.
Optionally gives back an indexed DenseMle.
Sourcepub fn combine_mles(mles: Vec<DenseMle<F>>) -> DenseMle<F>
pub fn combine_mles(mles: Vec<DenseMle<F>>) -> DenseMle<F>
Merges the MLEs into a single MLE by simply concatenating them.
Sourcepub fn expression(self) -> Expression<F, ProverExpr>
pub fn expression(self) -> Expression<F, ProverExpr>
Creates an expression from the current MLE.
Sourcepub fn get_bound_point(&self) -> Vec<F>
pub fn get_bound_point(&self) -> Vec<F>
Returns the evaluation challenges for a fully-bound MLE.
Note that this function panics if a particular challenge is neither fixed nor bound!